<?php
namespace Neuron\Person\Skill;

use Neuron\Generic\Result;
use Neuron\Generic\Entity\Map;

class Type extends \Neuron\Generic\Entity\Mapper {
    
    protected $_storage;

    public function __construct(Type\Storage\Skeleton $storage, $data = array()) {

        $this->_storage = $storage;

        parent::__construct(
            $data, 
            array(
                new Map('skill_type_id'),
                new Map('skill_code'),
                new Map('skill_name')
            ), 
            parent::CASE_INSENSITIVE
        );
    }

    public function save($update = false){
		if ($id = $this->_storage->save($this, $update)) {
			$this->skill_type_id = $id;
			return true;
		}
		
		return false;
    }

	public function create($data = array())
    {
		$result = new Result();
		$update = false;
		if ($data['skill_type_id']) {
			$update = true;
		}

		//create data relation
		$param = $this->pull();
		foreach ($data as $k => $v) {
			if (array_key_exists($k, $param)) {
				$param[$k] = $v;
			}
		}

		$this->push($param);
		if ($this->save($update)) {
			$result->data = $this->skill_type_id;
			$result->info = 'Success save type skill';
		} else {
			//gagal
			$result->code = 51;
			$result->info = 'Failed save type skill';
		}

		return $result;
    }

	public function delete($id) {
		/* init */
		$result = new Result();
		try {
			/* loaded? */
		
			if ($this->_storage->remove($id)) {

				$result->info = 'Success terminate type skill';
			} else {

				//gagal
				$result->code = 51;
				$result->info = 'Failed terminate type skill';

			}
				
			return $result;
		} catch (\Exception $ex) {
			error_log('Error at ' . $ex->getFile() . ' line ' . $ex->getLine() . ': ' . $ex->getMessage());
			$result->code = 500;
			$result->info = $ex->getMessage();
			return $result;
		}
    }

	public function load($id) {
		if ($data = $this->_storage->load($id)) {
			$this->push($data);
			return true;
		}

		return false;
    }
    
}